.. _install-ubuntu:


Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the ec2-api service on the
controller node for Ubuntu (LTS).

It assumes that you already have a working OpenStack environment with
at least the following components installed: Compute, Networking, Block Storage,
Identity, Image.

.. toctree::
   :maxdepth: 1

   install-sh.rst
   install-manual.rst
   install-devstack.rst
